@@ -16,6 +16,20 @@ from .timers import default_timer
 from .compat import XRANGE, PY3
 
 
+class NameWrapper(object):
+
+    def __init__(self, target):
+        self.target = target
+
+    def __str__(self):
+        name = self.target.__module__ + "." if hasattr(self.target, '__module__') else ""
+        name += self.target.__name__ if hasattr(self.target, '__name__') else repr(self.target)
+        return name
+
+    def __repr__(self):
+        return "NameWrapper(%s)" % repr(self.target)
+
+
 def loadtimer(string):
     if "." not in string:
         raise argparse.ArgumentTypeError("Value for --benchmark-timer must be in dotted form. Eg: 'module.attr'.")
@@ -23,14 +37,14 @@ def loadtimer(string):
     if mod == 'pep418':
         if PY3:
             import time
-            return getattr(time, attr)
+            return NameWrapper(getattr(time, attr))
         else:
             from . import pep418
-            return getattr(pep418, attr)
+            return NameWrapper(getattr(pep418, attr))
     else:
         __import__(mod)
         mod = sys.modules[mod]
-        return getattr(mod, attr)
+        return NameWrapper(getattr(mod, attr))
 
 
 def loadsort(string):
@@ -54,28 +68,28 @@ def pytest_addoption(parser):
     group = parser.getgroup("benchmark")
     group.addoption(
         "--benchmark-min-time",
-        action="store", type=Decimal, default=Decimal("0.1"),
-        help="Minimum time per round."
+        action="store", type=SecondsDecimal, default=SecondsDecimal("0.000025"),
+        help="Minimum time per round. Default: %(default)s"
     )
     group.addoption(
         "--benchmark-max-time",
-        action="store", type=Decimal, default=Decimal("1.0"),
-        help="Maximum time to spend in a benchmark."
+        action="store", type=SecondsDecimal, default=SecondsDecimal("1.0"),
+        help="Maximum time to spend in a benchmark. Default: %(default)s"
     )
     group.addoption(
         "--benchmark-min-rounds",
         action="store", type=loadrounds, default=5,
-        help="Minimum rounds, even if total time would exceed `--max-time`."
+        help="Minimum rounds, even if total time would exceed `--max-time`. Default: %(default)s"
     )
     group.addoption(
         "--benchmark-sort",
         action="store", type=loadsort, default="min",
-        help="Column to sort on. Can be one of: 'min', 'max', 'mean' or 'stddev' ."
+        help="Column to sort on. Can be one of: 'min', 'max', 'mean' or 'stddev'. Default: %(default)s"
     )
     group.addoption(
         "--benchmark-timer",
-        action="store", type=loadtimer, default=default_timer,
-        help="Timer to use when measuring time."
+        action="store", type=loadtimer, default=NameWrapper(default_timer),
+        help="Timer to use when measuring time. Default: %(default)s"
     )
     group.addoption(
         "--benchmark-warmup",
@@ -132,7 +146,7 @@ class BenchmarkFixture(object):
         self._disable_gc = disable_gc
         self._name = name
         self._group = group
-        self._timer = timer
+        self._timer = timer.target
         self._min_rounds = min_rounds
         self._max_time = float(max_time)
         self._min_time = float(min_time)
@@ -214,6 +228,15 @@ def time_format(value):
     return "{0:.2f}{1:s}".format(value * adjustment, unit)
 
 
+class SecondsDecimal(Decimal):
+
+    def __float__(self):
+        return float(super(SecondsDecimal, self).__str__())
+
+    def __str__(self):
+        return "{0}s".format(time_format(float(super(SecondsDecimal, self).__str__())))
+
+
 class DiagnosticLogger(object):
     def __init__(self, verbose
                  # , capman
@@ -257,6 +280,8 @@ class BenchmarkSession(object):
             node = request.node
             marker = node.get_marker("benchmark")
             options = marker.kwargs if marker else {}
+            if 'timer' in options:
+                options['timer'] = NameWrapper(options['timer'])
             benchmark = BenchmarkFixture(
                 node.name,
                 add_stats=self._benchmarks.append,
@@ -287,9 +312,7 @@ class BenchmarkSession(object):
         if not self._benchmarks:
             return
 
-        timer = self._options.get('timer') or 'default'
-        timer_name = timer.__module__ + "." if hasattr(timer, '__module__') else ""
-        timer_name += timer.__name__ if hasattr(timer, '__name__') else repr(timer)
+        timer = self._options.get('timer')
 
         groups = defaultdict(list)
         for bench in self._benchmarks:
@@ -322,14 +345,15 @@ class BenchmarkSession(object):
                     len("{0:.4f}".format(benchmark[prop] * adjustment))
                     for benchmark in benchmarks
                 ))
+
             tr.write_line(
-                " benchmark{2}: {0} tests, min {1.min_rounds} rounds (of min {1.min_time:f}s),"
-                " {1.max_time:f}s max time, timer: {3} ".format(
-                    len(benchmarks),
-                    type("", (), self._options),
-                    "" if group is None else " %r" % group,
-                    timer_name,
-                ).center(sum(widths.values()), '-'),
+                (" benchmark%(name)s: %(count)s tests, min %(min_rounds)s rounds (of min %(min_time)s),"
+                 " %(max_time)s max time, timer: %(timer)s " % dict(
+                     self._options,
+                     count=len(benchmarks),
+                     name="" if group is None else " %r" % group,
+                     timer=timer,
+                 )).center(sum(widths.values()), '-'),
                 yellow=True,
             )
             tr.write_line(labels["name"].ljust(widths["name"]) + "".join(
